//
//  FlybitsContextSDK.h
//  FlybitsContextSDK
//
//  Created by Caio on 2019-04-29.
//  Copyright © 2019 Flybits. All rights reserved.
//

#import <Foundation/Foundation.h>

//! Project version number for FlybitsContextSDK.
FOUNDATION_EXPORT double FlybitsContextSDKVersionNumber;

//! Project version string for FlybitsContextSDK.
FOUNDATION_EXPORT const unsigned char FlybitsContextSDKVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsContextSDK/PublicHeader.h>


